summaryrefslogtreecommitdiff
path: root/gnu/CORBA/Poa/ORB_1_4.java
diff options
context:
space:
mode:
authorAndrew John Hughes <gnu_andrew@member.fsf.org>2005-08-16 16:22:34 +0000
committerAndrew John Hughes <gnu_andrew@member.fsf.org>2005-08-16 16:22:34 +0000
commit988ea14cc6a504c6d5c7b9bfcbc01ca2b0a4e432 (patch)
tree0ee0ebd2e7d7a1b0b00edf51b48286965b1b4fca /gnu/CORBA/Poa/ORB_1_4.java
parente439fd75db6107e87660301775017154f05e1c06 (diff)
downloadclasspath-988ea14cc6a504c6d5c7b9bfcbc01ca2b0a4e432.tar.gz
2005-08-16 Andrew John Hughes <gnu_andrew@member.fsf.org>
* Merge of HEAD-->generics-branch for 2005/08/07-2005/08/14.
Diffstat (limited to 'gnu/CORBA/Poa/ORB_1_4.java')
-rw-r--r--gnu/CORBA/Poa/ORB_1_4.java11
1 files changed, 9 insertions, 2 deletions
diff --git a/gnu/CORBA/Poa/ORB_1_4.java b/gnu/CORBA/Poa/ORB_1_4.java
index 6302ddf12..00ca3bf76 100644
--- a/gnu/CORBA/Poa/ORB_1_4.java
+++ b/gnu/CORBA/Poa/ORB_1_4.java
@@ -39,6 +39,7 @@ exception statement from your version. */
package gnu.CORBA.Poa;
import gnu.CORBA.Functional_ORB;
+import gnu.CORBA.DynAn.gnuDynAnyFactory;
import org.omg.CORBA.BAD_PARAM;
import org.omg.CORBA.OBJECT_NOT_EXIST;
@@ -62,10 +63,15 @@ public class ORB_1_4
* Maps the active threads to the invocation data ("Current's").
*/
public gnuPoaCurrent currents = new gnuPoaCurrent();
+
+ /**
+ * Creates dynamic anys.
+ */
+ public gnuDynAnyFactory factory = new gnuDynAnyFactory(this);
/**
* Calls the parent constructor and additionally puts the "RootPOA" and
* "RootPOAManager" into initial references.
*/
public ORB_1_4()
{
@@ -84,6 +90,7 @@ public class ORB_1_4
initial_references.put("RootPOA", rootPOA);
initial_references.put("RootPOAManager", rootPOA.the_POAManager());
initial_references.put("POACurrent", currents);
+ initial_references.put("DynAnyFactory", factory);
}
/**
@@ -62,10 +63,15 @@ public class ORB_1_4
/**
- * Calls the parent constructor and additionally puts the "RootPOA" and
- * "RootPOAManager" into initial references.
+ * Calls the parent constructor and additionally puts the "RootPOA",
+ * "RootPOAManager", "POACurrent" and "DynAnyFactory" into initial references.
*/
public ORB_1_4()